@@ -470,20 +470,15 @@ PROT_EnchashDecrypter.SALT_LENGTH = PROT_EnchashDecrypter.DATABASE_SALT.length;
 PROT_EnchashDecrypter.MAX_DOTS = 5;
 
 PROT_EnchashDecrypter.REs = {};
-PROT_EnchashDecrypter.REs.FIND_DODGY_CHARS = 
-  new RegExp("[\x01-\x1f\x7f-\xff]+");
-PROT_EnchashDecrypter.REs.FIND_DODGY_CHARS_GLOBAL = 
+PROT_EnchashDecrypter.REs.FIND_DODGY_CHARS_GLOBAL =
   new RegExp("[\x01-\x1f\x7f-\xff]+", "g");
-PROT_EnchashDecrypter.REs.FIND_END_DOTS = new RegExp("^\\.+|\\.+$");
-PROT_EnchashDecrypter.REs.FIND_END_DOTS_GLOBAL = 
+PROT_EnchashDecrypter.REs.FIND_END_DOTS_GLOBAL =
   new RegExp("^\\.+|\\.+$", "g");
-PROT_EnchashDecrypter.REs.FIND_MULTIPLE_DOTS = new RegExp("\\.{2,}");
-PROT_EnchashDecrypter.REs.FIND_MULTIPLE_DOTS_GLOBAL = 
+PROT_EnchashDecrypter.REs.FIND_MULTIPLE_DOTS_GLOBAL =
   new RegExp("\\.{2,}", "g");
 PROT_EnchashDecrypter.REs.FIND_TRAILING_SPACE =
   new RegExp("^(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}) ");
-PROT_EnchashDecrypter.REs.FIND_TRAILING_DOTS = new RegExp("\\.+$");
-PROT_EnchashDecrypter.REs.POSSIBLE_IP = 
+PROT_EnchashDecrypter.REs.POSSIBLE_IP =
   new RegExp("^((?:0x[0-9a-f]+|[0-9\\.])+)$", "i");
 PROT_EnchashDecrypter.REs.FIND_BAD_OCTAL = new RegExp("(^|\\.)0\\d*[89]");
 PROT_EnchashDecrypter.REs.IS_OCTAL = new RegExp("^0[0-7]*$");
@@ -569,11 +564,14 @@ PROT_EnchashDecrypter.prototype.parseRegExps = function(data) {
  * type -url.
  *
  * @param url String to canonicalize
+ * @param opt_collapseSlashes Boolean true if we want to collapse slashes in
+ *        the path
  *
  * @returns String containing the canonicalized url (maximally url-decoded
  *          with hostname normalized, then specially url-encoded)
  */
-PROT_EnchashDecrypter.prototype.getCanonicalUrl = function(url) {
+PROT_EnchashDecrypter.prototype.getCanonicalUrl = function(url,
+                                                        opt_collapseSlashes) {
   var urlUtils = Cc["@mozilla.org/url-classifier/utils;1"]
                  .getService(Ci.nsIUrlClassifierUtils);
   var escapedUrl = urlUtils.canonicalizeURL(url);
@@ -589,6 +587,13 @@ PROT_EnchashDecrypter.prototype.getCanonicalUrl = function(url) {
                   .getService(Ci.nsIIOService);
   var urlObj = ioService.newURI(escapedUrl, null, null);
   urlObj.host = host;
+  if (opt_collapseSlashes) {
+    // Collapse multiple slashes in the path into a single slash.
+    // We end up collapsing slashes in the query string, but it's unlikely
+    // that this would lead to a false positive and it's much simpler to do
+    // this.
+    urlObj.path = urlObj.path.replace(/\/+/g, "/");
+  }
   return urlObj.asciiSpec;
 }
 
@@ -643,9 +648,6 @@ PROT_EnchashDecrypter.prototype.getCanonicalHost = function(str, opt_maxDots) {
 }
 
 PROT_EnchashDecrypter.prototype.parseIPAddress_ = function(host) {
-
-  host = host.replace(this.REs_.FIND_TRAILING_DOTS_GLOBAL, "");
-
   if (host.length <= 15) {
     // The Windows resolver allows a 4-part dotted decimal IP address to
     // have a space followed by any old rubbish, so long as the total length
@@ -998,19 +1000,18 @@ UrlClassifierTableUrl.inherits(UrlClassifierTable);
  * Look up a URL in a URL table
  */
 UrlClassifierTableUrl.prototype.exists = function(url, callback) {
-  // nsIUrlClassifierUtils.canonicalizeURL is the old way of canonicalizing a
-  // URL.  Unfortunately, it doesn't normalize numeric domains so alternate IP
-  // formats (hex, octal, etc) won't trigger a match.
-  // this.enchashDecrypter_.getCanonicalUrl does the right thing and
-  // normalizes a URL to 4 decimal numbers, but the update server may still be
-  // giving us encoded IP addresses.  So to be safe, we check both cases.
   var urlUtils = Cc["@mozilla.org/url-classifier/utils;1"]
                  .getService(Ci.nsIUrlClassifierUtils);
-  var oldCanonicalized = urlUtils.canonicalizeURL(url);
-  var canonicalized = this.enchashDecrypter_.getCanonicalUrl(url);
-  G_Debug(this, "Looking up: " + url + " (" + oldCanonicalized + " and " +
-                canonicalized + ")");
-  (new ExistsMultiQuerier([oldCanonicalized, canonicalized],
+  // We plan on having the server collapse multiple slashes in the path.
+  // Until this happens, we check both the raw url and the url with multiple
+  // slashes removed.
+  var urls = [
+    this.enchashDecrypter_.getCanonicalUrl(url),
+    this.enchashDecrypter_.getCanonicalUrl(url, true) /* collapse slashes */
+  ];
+
+  G_Debug(this, "Looking up: " + url + " (" + urls + ")");
+  (new ExistsMultiQuerier(urls,
                           this.name,
                           callback)).run();
 }
@@ -1101,7 +1102,7 @@ UrlClassifierTableEnchash.prototype.exists = function(url, callback) {
   // Run the possible domains against the db.
   (new EnchashMultiQuerier(possible, this.name, callback, url)).run();
 }
-//@line 46 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierTable.js"
+//@line 46 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierTable.js"
 
 var modScope = this;
 function Init() {
