@@ -1,6 +1,6 @@
-//@line 40 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 40 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 
-//@line 42 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 42 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 var helpBrowser;
 var helpSearchPanel;
 var emptySearch;
@@ -12,16 +12,16 @@ var helpGlossaryPanel;
 var strBundle;
 var gTocDSList = "";
 
-//@line 54 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 54 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 const NC = "http://home.netscape.com/NC-rdf#";
 const MAX_LEVEL = 40; // maximum depth of recursion in search datasources.
 const MAX_HISTORY_MENU_ITEMS = 6;
 
-//@line 68 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 68 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 const platform = "unix";
-//@line 72 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 72 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 
-//@line 74 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 74 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 const RDF = Components.classes["@mozilla.org/rdf/rdf-service;1"]
     .getService(Components.interfaces.nsIRDFService);
 const RDF_ROOT = RDF.GetResource("urn:root");
@@ -48,7 +48,7 @@ var RE;
 
 var helpFileURI;
 var helpFileDS;
-//@line 102 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 102 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 var helpBaseURI;
 
 /* defaultTopic is either set
@@ -62,7 +62,7 @@ var defaultTopic;
 
 const NSRESULT_RDF_SYNTAX_ERROR = 0x804e03f7;
 
-//@line 119 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 119 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function displayTopic(topic) {
     // Get the page to open.
     var uri = getLink(topic);
@@ -75,7 +75,7 @@ function displayTopic(topic) {
       loadURI(uri);
 }
 
-//@line 132 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 132 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function init() {
   // Cache panel references.
   helpSearchPanel = document.getElementById("help-search-panel");
@@ -84,6 +84,12 @@ function init() {
   helpGlossaryPanel = document.getElementById("help-glossary-panel");
   helpBrowser = document.getElementById("help-content");
 
+  // Turn off unnecessary features for security
+  helpBrowser.docShell.allowJavascript = false;
+  helpBrowser.docShell.allowPlugins = false;
+  helpBrowser.docShell.allowSubframes = false;
+  helpBrowser.docShell.allowMetaRedirects = false;
+
   strBundle = document.getElementById("bundle_help");
   emptySearchText = strBundle.getString("emptySearchText");
 
@@ -156,7 +162,7 @@ function hideSearchSidebar(aEvent) {
   tableOfContents.removeAttribute("hidden");
 }
 
-//@line 216 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 222 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function loadHelpRDF() {
   if (!helpFileDS) {
     try {
@@ -231,12 +237,12 @@ function loadHelpRDF() {
   }
 }
 
-//@line 292 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 298 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function filterDatasourceByPlatform(aDatasource) {
   filterNodeByPlatform(aDatasource, RDF_ROOT, 0);
 }
 
-//@line 298 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 304 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function filterNodeByPlatform(aDatasource, aCurrentResource, aCurrentLevel) {
   if (aCurrentLevel > MAX_LEVEL) {
      log("Datasources over " + MAX_LEVEL + " levels deep are unsupported.");
@@ -253,7 +259,7 @@ function filterNodeByPlatform(aDatasource, aCurrentResource, aCurrentLevel) {
   }
 }
 
-//@line 317 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 323 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function filterSeqByPlatform(aDatasource, aNode, aCurrentLevel) {
   // get nc:subheading children into an enumerator
   var RDFC = Components.classes["@mozilla.org/rdf/container;1"]
@@ -286,7 +292,7 @@ function filterSeqByPlatform(aDatasource, aNode, aCurrentLevel) {
   }
 }
 
-//@line 351 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 357 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function normalizeLinks(helpBaseURI, links) {
   if (!helpBaseURI) {
     return links;
@@ -328,7 +334,7 @@ function getLink(ID) {
     return null;
 }
 
-//@line 394 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 400 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function getHelpFileURI() {
     return helpFileURI;
 }
@@ -545,7 +551,7 @@ function focusSearch() {
   searchBox.focus();
 }
 
-//@line 612 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 618 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function doFind() {
     if (document.getElementById("help-search-sidebar").hidden)
       showSearchSidebar();
@@ -695,7 +701,7 @@ function getLiteralValue(literal, defaultValue) {
     return null;
 }
 
-//@line 762 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 768 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function log(aText) {
     CONSOLE_SERVICE.logStringMessage(aText);
 }
@@ -712,7 +718,7 @@ function getBoolPref (aPrefname, aDefault)
   }
 }
 
-//@line 779 "/export/home/mozilla/uild/firefox-2.0.0.10/src/mozilla/toolkit/components/help/content/help.js"
+//@line 785 "/export/home/mozilla/uild/firefox-2.0.0.17/src/mozilla/toolkit/components/help/content/help.js"
 function getXulWin()
 {
   window.QueryInterface(Components.interfaces.nsIInterfaceRequestor);
